@@ -22,13 +22,14 @@ B<BETA CODE ONLY - NOT TO BE USED IN PRODUCTION SCRIPTS>
 use strict ;
 use Carp ;
 
-our $VERSION = "1.000" ;
+our $VERSION = "1.001" ;
 
 
 #============================================================================================
 # USES
 #============================================================================================
 use App::Framework::Feature ;
+use Net::SMTP ;
 
 #============================================================================================
 # OBJECT HIERARCHY
@@ -170,6 +171,34 @@ sub init_class
 
 #============================================================================================
 
+#----------------------------------------------------------------------------
+
+=item B< mail([%args]) >
+
+Returns the mail object. If %args are specified they are used to set the L</FIELDS>
+
+=cut
+
+sub mail
+{
+	my $this = shift ;
+	my (%args) = @_ ;
+
+	$this->set(%args) if %args ;
+	return $this ;
+}
+
+#----------------------------------------------------------------------------
+
+=item B< Mail([%args]) >
+
+Alias to L</mail>
+
+=cut
+
+*Mail = \&mail ;
+
+
 
 #--------------------------------------------------------------------------------------------
 
